@@ -4,15 +4,15 @@
 //! [Platform::terminate](crate::platform::Platform::terminate) on the given platform.
 use std::sync::Arc;
 
-use tokio::signal::unix::SignalKind;
-
 use crate::platform::Platform;
 
 /// Installs a signal handler for the given platform which awaits either a **CTRL+C** or **SIGHUP**.
+#[cfg(not(windows))]
 pub fn install(platform: Arc<Platform>) {
     let _ = tokio::spawn(async move {
         let ctrl_c = tokio::signal::ctrl_c();
-        let mut sig_hup = tokio::signal::unix::signal(SignalKind::hangup()).unwrap();
+        let mut sig_hup =
+            tokio::signal::unix::signal(tokio::signal::unix::SignalKind::hangup()).unwrap();
 
         tokio::select! {
             _ = ctrl_c => {
@@ -26,3 +26,18 @@ pub fn install(platform: Arc<Platform>) {
         }
     });
 }
+
+/// Installs a signal handler for the given platform which awaits a **CTRL+C**.
+#[cfg(windows)]
+pub fn install(platform: Arc<Platform>) {
+    let _ = tokio::spawn(async move {
+        let ctrl_c = tokio::signal::ctrl_c();
+
+        tokio::select! {
+            _ = ctrl_c => {
+                log::info!("Received CTRL-C. Shutting down...");
+                platform.terminate();
+            },
+        }
+    });
+}
